(define martians (list
  (route-filter (cidr (ip 0 0 0 0) 0) 'exact '())
  (route-filter (cidr (ip 10 0 0 0) 8) 'orlonger '())
  (route-filter (cidr (ip 127 0 0 0) 8) 'orlonger '())
  (route-filter (cidr (ip 169 254 0 0) 16) 'orlonger '())
  (route-filter (cidr (ip 172 16 0 0) 12) 'orlonger '())
  (route-filter (cidr (ip 192 0 2 0) 24) 'orlonger '())
  (route-filter (cidr (ip 192 88 99 1) 32) 'exact '())
  (route-filter (cidr (ip 192 168 0 0) 16) 'orlonger '())
  (route-filter (cidr (ip 198 18 0 0) 15) 'orlonger '())
  (route-filter (cidr (ip 224 0 0 0) 4) 'orlonger '())
  (route-filter (cidr (ip 240 0 0 0) 4) 'orlonger '())))

(define sanity-in (term martians (list (reject))))

(define (neighbor-remove-sanity-in n)
  (neighbor-import-update n [lambda (policies)
    (map [lambda (policy) 
      (filter [lambda (term) 
        (not (eq? term sanity-in))
      ] policy)
    ] policies)
  ]))

(define (as-remove-sanity-in as)
  (as-routers-update [lambda (rs)
    (map [lambda (r)
      (router-neighbors-update [lambda (ns)
        (map neighbor-remove-sanity-in ns)
      ] r)
    ] rs)
  ] as))

(define (martian? p)
  (define (denote m)
    (prefix-compare (route-filter-modifier m) (route-filter-prefix m) p))
  (ormap denote martians))

(define (load-all)
  (load-as '("configs/atla.conf"
             "configs/chic.conf"
             "configs/clev.conf"
             "configs/hous.conf"
             "configs/kans.conf"
             "configs/losa.conf"
             "configs/newy32aoa.conf"
             "configs/salt.conf"
             "configs/seat.conf"
             "configs/wash.conf")))

(define (load-atla)
  (load-as '("configs/atla.conf")))

(define (load-atla-no-sanity)
  (as-remove-sanity-in (load-atla)))

(define (no-martian r p al)
  (if (and (martian? p) (available? al))
    false
    true))

(define (policy args)
  no-martian)

(define (as args)
  (cond
    [(equal? (first args) "all") (load-all)]
    [(equal? (first args) "atla") (load-atla)]
    [(equal? (first args) "atla-no-sanity") (load-atla-no-sanity)]))
